#ifndef HLTrigger_Muon_Test_HLTMuonRateAnalyzer_H
#define HLTrigger_Muon_Test_HLTMuonRateAnalyzer_H

/** \class HLTMuonRateAnalyzer
 *  Get L1/HLT efficiency/rate plots
 *
 *  \author J. Alcaraz
 */

// Base Class Headers
#include "FWCore/Framework/interface/EDAnalyzer.h"
#include "FWCore/Utilities/interface/InputTag.h"
#include <vector>

class TFile;
class TH1F;

class HLTMuonRateAnalyzer: public edm::EDAnalyzer {
public:
  /// Constructor
  HLTMuonRateAnalyzer(const edm::ParameterSet& pset);

  /// Destructor
  virtual ~HLTMuonRateAnalyzer();

  // Operations

  void analyze(const edm::Event & event, const edm::EventSetup& eventSetup);

  virtual void beginJob() ;
  virtual void endJob() ;

private:
  // Input from cfg file
  edm::InputTag theGenLabel;
  edm::InputTag theL1CollectionLabel;
  std::vector<edm::InputTag> theHLTCollectionLabels;
  double theL1ReferenceThreshold;
  std::vector<double> theNSigmas;
  unsigned int theNumberOfObjects;
  double theCrossSection;
  double theLuminosity;
  double thePtMin;
  double thePtMax;
  unsigned int theNbins;
  std::string theRootFileName;

  // The output Root file
  TFile* theFile;

  // Histograms
  TH1F* hL1eff;
  TH1F* hL1rate;
  std::vector <TH1F*> hHLTeff;
  std::vector <TH1F*> hHLTrate;

  // Counter of events (weighted in general)
  double theNumberOfEvents;
  
};
#endif
